@@ -17,7 +17,13 @@ struct mirror_t {
  */
 #define MANUAL_ENTRY "manual"
 
-#define SUITE_LENGTH 32
+/*
+ * Allow to read the full Architectures: line from Release file,
+ * which is up to 123 bytes long at time of writing.
+ */
+#define BUFFER_LENGTH 256
+
+#define SUITE_LENGTH 128
 
 /* Stack of suites */
 static const char suites[][SUITE_LENGTH] = {
@@ -43,6 +49,7 @@ static const char suites[][SUITE_LENGTH] = {
 struct release_t {
 	char *name;
 	char *suite;
+	char *archs;
 	int status;
 };
 
